@@ -1,5 +1,3 @@
-# $Id: Compressed.pm,v 1.6 2001/08/09 18:13:10 btrott Exp $
-
 package Crypt::OpenPGP::Compressed;
 use strict;
 
@@ -104,12 +102,10 @@ Crypt::OpenPGP::Compressed - Compressed data packets
 
     use Crypt::OpenPGP::Compressed;
 
+    my $data = 'serialized openpgp packets';
     my $cdata = Crypt::OpenPGP::Compressed->new( Data => $data );
     my $serialized = $cdata->save;
 
-    my $cdata = Crypt::OpenPGP::Compressed->parse($buffer);
-    my $data = $cdata->decompress;
-
 =head1 DESCRIPTION
 
 I<Crypt::OpenPGP::Compressed> implements compressed data packets,
